==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/world/ModPlacedFeatures.java <==
package net.tlotd.world;

import net.minecraft.class_2960;
import net.minecraft.class_2975;
import net.minecraft.class_5321;
import net.minecraft.class_5843;
import net.minecraft.class_6795;
import net.minecraft.class_6796;
import net.minecraft.class_6797;
import net.minecraft.class_6880;
import net.minecraft.class_7891;
import net.minecraft.class_7924;
import net.tlotd.TLOTD;

import java.util.List;

public class ModPlacedFeatures {
    public static final class_5321<class_6796> MARBLE_PLACED_KEY = registerKey("marble_placed");
    public static final class_5321<class_6796> LIMESTONE_PLACED_KEY = registerKey("limestone_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_PLACED_KEY = registerKey("red_deepslate_placed");

    public static final class_5321<class_6796> NETHER_SULFUR_ORE_PLACED_KEY = registerKey("nether_sulfur_ore_placed");
    public static final class_5321<class_6796> ENDSTONE_ENDURIUM_ORE_PLACED_KEY = registerKey("endstone_endurium_ore_placed");

    public static final class_5321<class_6796> LEAD_ORE_PLACED_KEY = registerKey("lead_ore_placed");
    public static final class_5321<class_6796> DEEPSLATE_URANIUM_ORE_PLACED_KEY = registerKey("deepslate_uranium_ore_placed");

    public static final class_5321<class_6796> DEEPSLATE_FOSSIL_PLACED_KEY = registerKey("deepslate_fossil_placed");
    public static final class_5321<class_6796> HELIORITE_ORE_PLACED_KEY = registerKey("heliorite_ore_placed");
    public static final class_5321<class_6796> PALLADIUM_ORE_PLACED_KEY = registerKey("palladium_ore_placed");
    public static final class_5321<class_6796> JURASSOLINE_ORE_PLACED_KEY = registerKey("jurassoline_ore_placed");
    public static final class_5321<class_6796> CINNABAR_ORE_PLACED_KEY = registerKey("cinnabar_ore_placed");
    public static final class_5321<class_6796> NEBULAR_ORE_PLACED_KEY = registerKey("nebular_ore_placed");

    public static final class_5321<class_6796> MITHRIL_ORE_PLACED_KEY = registerKey("mithril_ore_placed");

    public static final class_5321<class_6796> RED_GRAVEL_PLACED_KEY = registerKey("red_gravel_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_MARBLE_PLACED_KEY = registerKey("red_deepslate_marble_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_LIMESTONE_PLACED_KEY = registerKey("red_deepslate_limestone_placed");

    public static final class_5321<class_6796> RED_DEEPSLATE_FOSSIL_PLACED_KEY = registerKey("red_deepslate_fossil_placed");

    public static final class_5321<class_6796> RED_DEEPSLATE_SULFUR_ORE_PLACED_KEY = registerKey("red_deepslate_sulfur_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_QUARTZ_ORE_PLACED_KEY = registerKey("red_deepslate_quartz_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_IRON_ORE_PLACED_KEY = registerKey("red_deepslate_iron_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_COPPER_ORE_PLACED_KEY = registerKey("red_deepslate_copper_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_GOLD_ORE_PLACED_KEY = registerKey("red_deepslate_gold_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_REDSTONE_ORE_PLACED_KEY = registerKey("red_deepslate_redstone_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_EMERALD_ORE_PLACED_KEY = registerKey("red_deepslate_emerald_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_LAPIS_ORE_PLACED_KEY = registerKey("red_deepslate_lapis_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_DIAMOND_ORE_PLACED_KEY = registerKey("red_deepslate_diamond_ore_placed");

    public static final class_5321<class_6796> RED_DEEPSLATE_ZINC_ORE_PLACED_KEY = registerKey("red_deepslate_zinc_ore_placed");

    public static final class_5321<class_6796> MOON_ROCK_COAL_ORE_PLACED_KEY = registerKey("moon_rock_coal_ore_placed");
    public static final class_5321<class_6796> MOON_ROCK_IRON_ORE_PLACED_KEY = registerKey("moon_rock_iron_ore_placed");
    public static final class_5321<class_6796> MOON_ROCK_LUNAR_CALLAINUS_ORE_PLACED_KEY = registerKey("moon_rock_lunar_callainus_ore_placed");

    public static void bootstrap(class_7891<class_6796> context) {
        var configuredFeatureRegistryEntryLookup = context.method_46799(class_7924.field_41239);
        register(context, NETHER_SULFUR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.NETHER_SULFUR_ORE_KEY), ModOrePlacement.modifiersWithCount(8, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(128))));
        register(context, ENDSTONE_ENDURIUM_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.ENDSTONE_ENDURIUM_ORE_KEY), ModOrePlacement.modifiersWithCount(8, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(128))));

        register(context, MARBLE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MARBLE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(320))));
        register(context, LIMESTONE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.LIMESTONE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_KEY), ModOrePlacement.modifiersWithCount(8, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));

        register(context, LEAD_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.LEAD_ORE_KEY), ModOrePlacement.modifiersWithCount(4, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(128))));
        register(context, DEEPSLATE_URANIUM_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.DEEPSLATE_URANIUM_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));

        register(context, DEEPSLATE_FOSSIL_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.DEEPSLATE_FOSSIL_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, HELIORITE_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.HELIORITE_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, JURASSOLINE_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.JURASSOLINE_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, PALLADIUM_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.PALLADIUM_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, CINNABAR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.CINNABAR_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, NEBULAR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.NEBULAR_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, MITHRIL_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MITHRIL_ORE_KEY), ModOrePlacement.modifiersWithCount(12, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(128))));

        register(context, RED_GRAVEL_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_GRAVEL_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_MARBLE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_MARBLE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_LIMESTONE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_LIMESTONE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));

        register(context, RED_DEEPSLATE_FOSSIL_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_FOSSIL_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(128))));

        register(context, RED_DEEPSLATE_SULFUR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_SULFUR_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_QUARTZ_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_QUARTZ_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_IRON_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_IRON_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_COPPER_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_COPPER_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_GOLD_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_GOLD_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_REDSTONE_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_REDSTONE_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_EMERALD_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_EMERALD_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_LAPIS_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_LAPIS_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_DIAMOND_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_DIAMOND_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));

        register(context, RED_DEEPSLATE_ZINC_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_ZINC_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));

        register(context, MOON_ROCK_COAL_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MOON_ROCK_COAL_ORE_KEY), ModOrePlacement.modifiersWithCount(24, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, MOON_ROCK_IRON_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MOON_ROCK_IRON_ORE_KEY), ModOrePlacement.modifiersWithCount(32, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, MOON_ROCK_LUNAR_CALLAINUS_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MOON_ROCK_LUNAR_CALLAINUS_ORE_KEY), ModOrePlacement.modifiersWithCount(12, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
    }

    public static class_5321<class_6796> registerKey(String name) {
        return class_5321.method_29179(class_7924.field_41245, new class_2960(TLOTD.MOD_ID, name));
    }

    private static void register(class_7891<class_6796> context, class_5321<class_6796> key, class_6880<class_2975<?, ?>> configuration, List<class_6797> modifiers) {
        context.method_46838(key, new class_6796(configuration, List.copyOf(modifiers)));
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/world/ModPlacedFeatures.java <==
package net.tlotd.world;

import net.minecraft.class_2960;
import net.minecraft.class_2975;
import net.minecraft.class_5321;
import net.minecraft.class_5843;
import net.minecraft.class_6795;
import net.minecraft.class_6796;
import net.minecraft.class_6797;
import net.minecraft.class_6880;
import net.minecraft.class_7891;
import net.minecraft.class_7924;
import net.tlotd.TLOTD;

import java.util.List;

public class ModPlacedFeatures {
    public static final class_5321<class_6796> MARBLE_PLACED_KEY = registerKey("marble_placed");
    public static final class_5321<class_6796> LIMESTONE_PLACED_KEY = registerKey("limestone_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_PLACED_KEY = registerKey("red_deepslate_placed");

    public static final class_5321<class_6796> NETHER_SULFUR_ORE_PLACED_KEY = registerKey("nether_sulfur_ore_placed");
    public static final class_5321<class_6796> ENDSTONE_ENDURIUM_ORE_PLACED_KEY = registerKey("endstone_endurium_ore_placed");

    public static final class_5321<class_6796> LEAD_ORE_PLACED_KEY = registerKey("lead_ore_placed");
    public static final class_5321<class_6796> DEEPSLATE_URANIUM_ORE_PLACED_KEY = registerKey("deepslate_uranium_ore_placed");

    public static final class_5321<class_6796> DEEPSLATE_FOSSIL_PLACED_KEY = registerKey("deepslate_fossil_placed");
    public static final class_5321<class_6796> HELIORITE_ORE_PLACED_KEY = registerKey("heliorite_ore_placed");
    public static final class_5321<class_6796> PALLADIUM_ORE_PLACED_KEY = registerKey("palladium_ore_placed");
    public static final class_5321<class_6796> JURASSOLINE_ORE_PLACED_KEY = registerKey("jurassoline_ore_placed");
    public static final class_5321<class_6796> CINNABAR_ORE_PLACED_KEY = registerKey("cinnabar_ore_placed");
    public static final class_5321<class_6796> NEBULAR_ORE_PLACED_KEY = registerKey("nebular_ore_placed");

    public static final class_5321<class_6796> MITHRIL_ORE_PLACED_KEY = registerKey("mithril_ore_placed");

    public static final class_5321<class_6796> RED_GRAVEL_PLACED_KEY = registerKey("red_gravel_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_MARBLE_PLACED_KEY = registerKey("red_deepslate_marble_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_LIMESTONE_PLACED_KEY = registerKey("red_deepslate_limestone_placed");

    public static final class_5321<class_6796> RED_DEEPSLATE_FOSSIL_PLACED_KEY = registerKey("red_deepslate_fossil_placed");

    public static final class_5321<class_6796> RED_DEEPSLATE_SULFUR_ORE_PLACED_KEY = registerKey("red_deepslate_sulfur_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_QUARTZ_ORE_PLACED_KEY = registerKey("red_deepslate_quartz_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_IRON_ORE_PLACED_KEY = registerKey("red_deepslate_iron_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_COPPER_ORE_PLACED_KEY = registerKey("red_deepslate_copper_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_GOLD_ORE_PLACED_KEY = registerKey("red_deepslate_gold_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_REDSTONE_ORE_PLACED_KEY = registerKey("red_deepslate_redstone_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_EMERALD_ORE_PLACED_KEY = registerKey("red_deepslate_emerald_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_LAPIS_ORE_PLACED_KEY = registerKey("red_deepslate_lapis_ore_placed");
    public static final class_5321<class_6796> RED_DEEPSLATE_DIAMOND_ORE_PLACED_KEY = registerKey("red_deepslate_diamond_ore_placed");

    public static final class_5321<class_6796> RED_DEEPSLATE_ZINC_ORE_PLACED_KEY = registerKey("red_deepslate_zinc_ore_placed");

    public static final class_5321<class_6796> MOON_ROCK_COAL_ORE_PLACED_KEY = registerKey("moon_rock_coal_ore_placed");
    public static final class_5321<class_6796> MOON_ROCK_IRON_ORE_PLACED_KEY = registerKey("moon_rock_iron_ore_placed");
    public static final class_5321<class_6796> MOON_ROCK_LUNAR_CALLAINUS_ORE_PLACED_KEY = registerKey("moon_rock_lunar_callainus_ore_placed");

    public static final class_5321<class_6796> MEGA_GINKGO_TREE_PLACED_KEY = registerKey("mega_ginkgo_tree_placed");
    public static final class_5321<class_6796> GINKGO_TREE_PLACED_KEY = registerKey("ginkgo_tree_placed");

    public static void bootstrap(class_7891<class_6796> context) {
        var configuredFeatureRegistryEntryLookup = context.method_46799(class_7924.field_41239);
        register(context, NETHER_SULFUR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.NETHER_SULFUR_ORE_KEY), ModOrePlacement.modifiersWithCount(8, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(128))));
        register(context, ENDSTONE_ENDURIUM_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.ENDSTONE_ENDURIUM_ORE_KEY), ModOrePlacement.modifiersWithCount(8, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(128))));

        register(context, MARBLE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MARBLE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(320))));
        register(context, LIMESTONE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.LIMESTONE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_KEY), ModOrePlacement.modifiersWithCount(8, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));

        register(context, LEAD_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.LEAD_ORE_KEY), ModOrePlacement.modifiersWithCount(4, class_6795.method_39634(class_5843.method_33841(0), class_5843.method_33841(128))));
        register(context, DEEPSLATE_URANIUM_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.DEEPSLATE_URANIUM_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));

        register(context, DEEPSLATE_FOSSIL_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.DEEPSLATE_FOSSIL_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, HELIORITE_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.HELIORITE_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, JURASSOLINE_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.JURASSOLINE_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, PALLADIUM_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.PALLADIUM_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, CINNABAR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.CINNABAR_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, NEBULAR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.NEBULAR_ORE_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(0))));
        register(context, MITHRIL_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MITHRIL_ORE_KEY), ModOrePlacement.modifiersWithCount(12, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(128))));

        register(context, RED_GRAVEL_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_GRAVEL_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_MARBLE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_MARBLE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_LIMESTONE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_LIMESTONE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));

        register(context, RED_DEEPSLATE_FOSSIL_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_FOSSIL_KEY), ModOrePlacement.modifiersWithCount(2, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(128))));

        register(context, RED_DEEPSLATE_SULFUR_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_SULFUR_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_QUARTZ_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_QUARTZ_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_IRON_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_IRON_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_COPPER_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_COPPER_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_GOLD_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_GOLD_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_REDSTONE_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_REDSTONE_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_EMERALD_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_EMERALD_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_LAPIS_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_LAPIS_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, RED_DEEPSLATE_DIAMOND_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_DIAMOND_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));

        register(context, RED_DEEPSLATE_ZINC_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.RED_DEEPSLATE_ZINC_ORE_KEY), ModOrePlacement.modifiersWithCount(16, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));

        register(context, MOON_ROCK_COAL_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MOON_ROCK_COAL_ORE_KEY), ModOrePlacement.modifiersWithCount(24, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, MOON_ROCK_IRON_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MOON_ROCK_IRON_ORE_KEY), ModOrePlacement.modifiersWithCount(32, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));
        register(context, MOON_ROCK_LUNAR_CALLAINUS_ORE_PLACED_KEY, configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MOON_ROCK_LUNAR_CALLAINUS_ORE_KEY), ModOrePlacement.modifiersWithCount(12, class_6795.method_39634(class_5843.method_33841(-64), class_5843.method_33841(320))));

        register(context,
                MEGA_GINKGO_TREE_PLACED_KEY,
                configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.MEGA_GINKGO_KEY),
                ModTreePlacement.modifiersWithCountAndExtra(6, 0.1f, 3)
        );

        register(context,
                GINKGO_TREE_PLACED_KEY,
                configuredFeatureRegistryEntryLookup.method_46747(ModConfiguredFeatures.GINKGO_KEY),
                ModTreePlacement.modifiersWithCountAndExtra(6, 0.1f, 3)
        );
    }

    public static class_5321<class_6796> registerKey(String name) {
        return class_5321.method_29179(class_7924.field_41245, new class_2960(TLOTD.MOD_ID, name));
    }

    private static void register(class_7891<class_6796> context, class_5321<class_6796> key, class_6880<class_2975<?, ?>> configuration, List<class_6797> modifiers) {
        context.method_46838(key, new class_6796(configuration, List.copyOf(modifiers)));
    }
}
